@@ -107,8 +107,8 @@ void VideoWidget::start() {
 //    g_object_set(G_OBJECT(input_selector), "active-pad", gst_element_get_pad(video_crop, "src"), NULL);
     gst_element_set_state(pipeline, GST_STATE_PLAYING);
     gst_photography_set_scene_mode (GST_PHOTOGRAPHY (camera_src), GST_PHOTOGRAPHY_SCENE_MODE_CLOSEUP); // uncommented to fix focus although we are using crop
-    refocus();
     pipelineReady = true;
+    refocus();
 }
 void VideoWidget::stop() {
     gst_element_set_state(pipeline, GST_STATE_NULL);
@@ -503,7 +503,7 @@ void VideoWidget::getDeviceType() {
         qDebug( "Oh no... We're something else.");
 }
 void VideoWidget::refocus() {
-    if(!focusing) {
+    if(!focusing && pipelineReady) { // we are running and are not focusing.
         emit focusingValueChanged(true);
         gst_element_set_state (pipeline, GST_STATE_PAUSED);
 
@@ -514,7 +514,7 @@ void VideoWidget::refocus() {
 //        gst_element_set_state (pipeline, GST_STATE_READY); // causes some problems with flickering, should probably be uncommented
         gst_element_set_state (pipeline, GST_STATE_PLAYING);
     } else {
-        qDebug("VideoWidget::refocus(): Already attempting autofocus... Please wait :)");
+        qDebug("VideoWidget::refocus(): Already attempting autofocus or pipeline not ready... Please wait :)");
     }
 }
 void VideoWidget::setFocusing(bool enabled) {
